# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"/\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"\x1d\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User2\xfb\x01\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponseP\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGINREQUEST._serialized_start=44
  _LOGINREQUEST._serialized_end=91
  _LOGINRESPONSE._serialized_start=93
  _LOGINRESPONSE._serialized_end=148
  _USER._serialized_start=150
  _USER._serialized_end=197
  _USERCREATEREQUEST._serialized_start=199
  _USERCREATEREQUEST._serialized_end=275
  _USERCREATERESPONSE._serialized_start=277
  _USERCREATERESPONSE._serialized_end=347
  _USERGETREQUEST._serialized_start=349
  _USERGETREQUEST._serialized_end=378
  _USERGETRESPONSE._serialized_start=380
  _USERGETRESPONSE._serialized_end=448
  _USERLISTREQUEST._serialized_start=450
  _USERLISTREQUEST._serialized_end=482
  _USERLISTRESPONSE._serialized_start=484
  _USERLISTRESPONSE._serialized_end=553
  _USERAPI._serialized_start=556
  _USERAPI._serialized_end=807
# @@protoc_insertion_point(module_scope)
